@@ -1,6 +1,7 @@
 # -*- encoding: utf-8 -*-
 
 from django.db import models
+from django.utils.translation import ugettext_lazy as _
 
 from ..language.models import Language
 
@@ -8,28 +9,33 @@ from ..language.models import Language
 class MenuItem(models.Model):
     '''
     Stores menuitem information.
-    It is recommended to write urls in SEO format, e.g.: this_is_my_site_describing_something.
+    It is recommended to write urls in SEO format,
+    e.g.: this_is_my_site_describing_something.
     Is related to :model: `django_pages.Menu`.
     '''
 
-    lang = models.ForeignKey(Language)
-    menuitem_name = models.CharField('MenuItem name', max_length=200)
-    url = models.SlugField('Url', max_length=200, unique=True)
-    position = models.IntegerField('Position', blank=True)
+    lang = models.ForeignKey(Language, verbose_name=_('Language'))
+    menuitem_name = models.CharField(_('Menu item name'), max_length=200)
+    url = models.SlugField(
+        _('Url'),
+        help_text=_('It is recommended to write urls in SEO format, '
+                    'e.g.: this_is_my_site_describing_something.'),
+        max_length=200,
+        unique=True
+    )
+    position = models.IntegerField(_('Position'), blank=True)
 
     def __unicode__(self):
-
         return '%s - %s' % (self.menuitem_name, self.lang)
 
     def save(self, *args, **kwargs):
         """
-        if MenuItem does not contain position, set it to last_item's_position + 1
+        if MenuItem does not contain position,
+        set it to last_item's_position + 1
         """
-
         if not self.position:
 
             last_position = self.get_last_position()
-
             self.position = last_position + 1
 
         super(MenuItem, self).save(*args, **kwargs)
@@ -39,7 +45,6 @@ class MenuItem(models.Model):
         makes sure that there is no spaces in positioning after delete
         """
         super(MenuItem, self).delete(*args, **kwargs)
-
         self.reorder_items()
 
     def reorder_items(self):
@@ -48,7 +53,7 @@ class MenuItem(models.Model):
         """
 
         items = MenuItem.objects.filter(lang=self.lang).order_by('position')
-        
+
         for pos, item in enumerate(items):
             item.position = pos + 1
             item.save()
@@ -57,15 +62,12 @@ class MenuItem(models.Model):
         """
         returns last_item's_position or 0 (no items)
         """
-
         other_objects = MenuItem.objects.filter(lang=self.lang).order_by('-position')
 
         if other_objects.count():
-
             last_position = other_objects[0].position
 
         else:
-
             last_position = 0
 
         return last_position
@@ -74,9 +76,7 @@ class MenuItem(models.Model):
         """
         returns True if self.position is 1, False otherwise
         """
-
         if self.position == 1:
-
             return True
 
         return False
@@ -87,11 +87,9 @@ class MenuItem(models.Model):
 
         @return bool
         """
-
         last_position = self.get_last_position()
 
         if self.position == last_position:
-
             return True
 
         return False
@@ -100,33 +98,26 @@ class MenuItem(models.Model):
         """
         moves this item to self.position + 1
         """
-
         if self.is_last():
-
             pass
 
         else:
-
             self.swap_with(self.position + 1)
 
     def decrease_position(self):
         """
         moves this item to self.position - 1
         """
-
         if self.is_first():
-
             pass
 
         else:
-
             self.swap_with(self.position - 1)
 
     def swap_with(self, position):
         """
         handles item moving, makes sure there are no items with same position
         """
-
         try:
             object_to_swap_with = MenuItem.objects.get(lang=self.lang, position=position)
 
@@ -145,9 +136,11 @@ class MenuItem(models.Model):
 
         @return bool
         """
-
         if page_url == self.url or (self.page.index and self.page.active and page_url is None):
-
             return True
 
         return False
+
+    class Meta:
+        verbose_name = _('Menu item')
+        verbose_name_plural = _('Menu items')
