@@ -11,10 +11,15 @@ class SiteAdmin(admin.ModelAdmin):
 
         js = [
             '/static/admin/js/ckeditor/ckeditor.js',
-            '/static/admin/js/ckeditor/config.js',
             '/static/admin/js/ckeditor/start.js',
+            '/static/filebrowser/js/FB_CKEditor.js',
         ]
 
         css = {
             'ckeditor': ('/static/admin/js/ckeditor/contents.css',),
         }
+
+
+class ScriptAdmin(admin.ModelAdmin):
+
+    list_display = ('name', 'code')
